export * from './lib';
export * from 'typedarray-dts';
export declare type ITSType = typeof import('./index');
export declare type ITSTypeBuildIn = typeof import('./lib/_build-in');
export default ITSType;
